"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

var IronSelection = function () {
  function IronSelection(props) {
    _classCallCheck(this, IronSelection);

    this.selection = [];
    this.selectCallback = props && props.selectCallback;
  }
  /**
     * Retrieves the selected item(s).
     *
     * @method get
     * @returns Returns the selected item(s). If the multi property is true,
     * `get` will return an array, otherwise it will return
     * the selected item or undefined if there is no selection.
     */


  _createClass(IronSelection, [{
    key: "get",
    value: function get() {
      return this.multi ? this.selection.slice() : this.selection[0];
    }
    /**
       * Clears all the selection except the ones indicated.
       *
       * @method clear
       * @param {Array} excludes items to be excluded.
       */

  }, {
    key: "clear",
    value: function clear(excludes) {
      this.selection.slice().forEach(function (item) {
        if (!excludes || excludes.indexOf(item) < 0) {
          this.setItemSelected(item, false);
        }
      }, this);
    }
    /**
       * Indicates if a given item is selected.
       *
       * @method isSelected
       * @param {*} item The item whose selection state should be checked.
       * @returns Returns true if `item` is selected.
       */

  }, {
    key: "isSelected",
    value: function isSelected(item) {
      return this.selection.indexOf(item) >= 0;
    }
    /**
       * Sets the selection state for a given item to either selected or deselected.
       *
       * @method setItemSelected
       * @param {*} item The item to select.
       * @param {boolean} isSelected True for selected, false for deselected.
       */

  }, {
    key: "setItemSelected",
    value: function setItemSelected(item, isSelected) {
      if (item != null) {
        if (isSelected !== this.isSelected(item)) {
          // proceed to update selection only if requested state differs from current
          if (isSelected) {
            this.selection.push(item);
          } else {
            var i = this.selection.indexOf(item);
            if (i >= 0) {
              this.selection.splice(i, 1);
            }
          }
          if (this.selectCallback) {
            this.selectCallback(item, isSelected);
          }
        }
      }
    }
  }, {
    key: "select",
    value: function select(item) {
      if (this.multi) {
        this.toggle(item);
      } else if (this.get() !== item) {
        this.setItemSelected(this.get(), false);
        this.setItemSelected(item, true);
      }
    }
  }, {
    key: "toggle",
    value: function toggle(item) {
      this.setItemSelected(item, !this.isSelected(item));
    }
  }]);

  return IronSelection;
}();

exports.default = IronSelection;