'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _typeof = typeof Symbol === "function" && typeof Symbol.iterator === "symbol" ? function (obj) { return typeof obj; } : function (obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; };

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

/* eslint-disable */
var Breadcrumbs = function () {
  function Breadcrumbs(breadcrumbEl, graph, clickOnlyMode) {
    var breadcrumbs = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : [];
    var keys = arguments[4];

    _classCallCheck(this, Breadcrumbs);

    this.keys = keys;
    this.breadcrumbEl = breadcrumbEl;
    this.graph = graph;
    this.clickOnlyMode = clickOnlyMode;
    this.breadcrumbs = breadcrumbs;
    this.map = new WeakMap();
    this.ctx = this._createCanvas(breadcrumbEl);
    this._preShortenItems(this.breadcrumbs);
    return this;
  }

  /**
   * A getter that returns the size of the breadcrumb items - at full length.
   * It checks to see if it has a value, and if so, returns the cached one, so we don't have to calculate the value again.
   */


  _createClass(Breadcrumbs, [{
    key: '_addToWeakMap',

    /**
     * Adds the item that is passed in to the weakMap if it is not already there.
     */
    value: function _addToWeakMap(item) {
      var cachedItem = this.map.get(item) || null;
      if (!cachedItem) {
        this.map.set(item, item);
      }
    }
    /**
     * Called when the class is instantiated. it loops through all the passed in items, and calls the _getShortenedText method on
     * each item.
     */

  }, {
    key: '_preShortenItems',
    value: function _preShortenItems(items) {
      var _iteratorNormalCompletion = true;
      var _didIteratorError = false;
      var _iteratorError = undefined;

      try {
        for (var _iterator = items[Symbol.iterator](), _step; !(_iteratorNormalCompletion = (_step = _iterator.next()).done); _iteratorNormalCompletion = true) {
          var item = _step.value;

          this._getShortenedText(item);
        }
      } catch (err) {
        _didIteratorError = true;
        _iteratorError = err;
      } finally {
        try {
          if (!_iteratorNormalCompletion && _iterator.return) {
            _iterator.return();
          }
        } finally {
          if (_didIteratorError) {
            throw _iteratorError;
          }
        }
      }
    }
    /**
     * Returns the shortened version of the text in the item that is passed in, as well as add it into the map.
     * Checks for a cached version before it sets it.
     */

  }, {
    key: '_getShortenedText',
    value: function _getShortenedText(item) {
      var cachedItem = this.map.get(item) || {};
      var label = this._getItemProp(item, this.keys.label);
      if (!cachedItem.shortText && label.length > 13) {
        cachedItem.shortText = label.substr(0, 6) + '...' + label.substr(label.length - 6);
      } else if (!cachedItem.shortText) {
        cachedItem.shortText = label;
      }
      this.map.set(item, cachedItem);
      return cachedItem.shortText;
    }
    /**
     * Returns the size - in pixels - of the full size of the text in the passed in item, as well as add that info into the map.
     * Checks for a cached version before setting this value
     */

  }, {
    key: '_sizeOfIndividualFullItem',
    value: function _sizeOfIndividualFullItem(item) {
      var cachedItem = this.map.get(item) || {};
      var label = this._getItemProp(item, this.keys.label);
      cachedItem.fullSize = cachedItem.fullSize || parseInt(this.ctx.measureText(label).width, 10);
      this.map.set(item, cachedItem);
      return cachedItem.fullSize;
    }
    /**
     * Returns the size - in pixels - of the short size of the text in the passed in item, as well as add that info into the map.
     * Checks for a cached version before setting this value
     */

  }, {
    key: '_sizeOfIndividualShortItem',
    value: function _sizeOfIndividualShortItem(item) {
      var cachedItem = this.map.get(item) || {};
      cachedItem.shortSize = cachedItem.shortSize || parseInt(this.ctx.measureText(cachedItem.shortText).width, 10);
      this.map.set(item, cachedItem);
      return cachedItem.shortSize;
    }
    /**
     * Loops through the passed in array, and gets the size - in pixels - of all the items.
     * The size can be determined in either short or full text.
     * It takes into account the size of the px-icons, as well as padding on each item, and padding on the container.
     */

  }, {
    key: '_calculateSizeOfBreadcrumbs',
    value: function _calculateSizeOfBreadcrumbs(strArray) {
      var useFullSize = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : true;

      if (strArray) {
        var accum = 0,
            i = 0,
            len = strArray.length,
            sizeOfItem = void 0;
        // run through all the items, and get the sizes.
        for (i = 0; i < len; i++, sizeOfItem = null) {
          if (useFullSize) {
            sizeOfItem = this._sizeOfIndividualFullItem(strArray[i]);
          } else {
            sizeOfItem = this._sizeOfIndividualShortItem(strArray[i]);
          }
          var source = strArray[i].source ? strArray[i].source : strArray[i];
          // add the size of the of the item into our accumulator
          accum += sizeOfItem;
          // if the item has siblings, we need to add the size of the down chevron.
          if (this._getItemProp(strArray[i], this.keys.label) !== '...' && this.graph.hasSiblings(source) && !this.clickOnlyMode) {
            accum += 21;
          }
          // padding on each item (10 on each side)
          accum += 20;
          // right angle arrow - the last item doesn't get a right angle.
          if (i !== len - 1) {
            accum += this.clickOnlyMode ? 30 : 15;
          }
        }
        return accum + 10; // extra padding somewhere? slight miscalculation?
      }
    }
    /**
     * Creates/returns the canvas that we will use to measure the size of the text.
     * We also set the font and font size.
     */

  }, {
    key: '_createCanvas',
    value: function _createCanvas(breadcrumbEl) {
      var style = window.getComputedStyle(breadcrumbEl, null),
          fontSize = style.getPropertyValue('font-size'),
          fontFamily = style.getPropertyValue('font-family');
      var canvas = document.createElement('canvas');
      canvas.height = 20;
      canvas.width = 9999;
      var ctx = canvas.getContext('2d');
      ctx.font = fontSize + ' ' + fontFamily;
      return ctx;
    }
    /**
     * Fetches an item's property at the configured key. Used to dynamically
     * fetch the item's label, icon, children, etc. based on the configured
     * `keys` for the component.
     */

  }, {
    key: '_getItemProp',
    value: function _getItemProp(item, key) {
      if (item && (typeof item === 'undefined' ? 'undefined' : _typeof(item)) === 'object' && typeof key === 'string' && item.hasOwnProperty(key)) {
        return item[key];
      }
      return null;
    }
  }, {
    key: 'sizeOfFullBreadcrumbs',
    get: function get() {
      this.__sizeOfFullBreadcrumbs = this.__sizeOfFullBreadcrumbs || this._calculateSizeOfBreadcrumbs(this.breadcrumbs);
      return this.__sizeOfFullBreadcrumbs;
    }
    /**
     * A getter that returns the short size of the breadcrumb items excluding the last item.
     */

  }, {
    key: 'sizeOfAllShortenedItemsExcludingLastItem',
    get: function get() {
      return this._calculateSizeOfBreadcrumbs(this.breadcrumbs.slice(0, this.breadcrumbs.length - 1), false);
    }
    /**
     * A getter that returns the size of the full last item.
     */

  }, {
    key: 'sizeOfFullLastItem',
    get: function get() {
      return this._calculateSizeOfBreadcrumbs(this.breadcrumbs.slice(-1));
    }
    /**
     * A getter that returns the size of the short last item.
     */

  }, {
    key: 'sizeOfShortLastItem',
    get: function get() {
      return this._calculateSizeOfBreadcrumbs(this.breadcrumbs.slice(-1), false);
    }
    /**
     * A getter that returns the last item in the breadcrumb array.
     */

  }, {
    key: 'lastItemFull',
    get: function get() {
      return this.breadcrumbs.slice(-1)[0];
    }
    /**
     * A getter that returns the short version of the last item in the breadcrumbs array.
     */

  }, {
    key: 'lastItemShort',
    get: function get() {
      return this.shortenedItems.slice(-1)[0];
    }
    /**
     * A getter that returns an array of all the shortened items in the breadcrumbs array.
     */

  }, {
    key: 'shortenedItems',
    get: function get() {
      var _this = this;

      this.__shortenedItems = this.__shortenedItems || this.breadcrumbs.map(function (item) {
        var wrapper = {};
        wrapper.source = item;
        wrapper.isTruncated = true;
        var labelKey = _this.keys.label;
        var childrenKey = _this.keys.children;
        wrapper[labelKey] = _this._getShortenedText(item);
        wrapper[childrenKey] = _this._getItemProp(item, _this.keys.children);
        wrapper.selectedItem = item.selectedItem;
        wrapper.hasChildren = item.hasChildren;
        wrapper.isSelectable = item.isSelectable;
        return wrapper;
      });
      return this.__shortenedItems;
    }
    /**
     * A getter that returns the size - in pixels - of the overflow ellipsis.
     */

  }, {
    key: 'sizeOfEllipsis',
    get: function get() {
      return 36;
    }
    /**
     * A getter that returns the size - in pixels - of all the shortened breadcrumbs items.
     */

  }, {
    key: 'sizeOfAllShortenedItems',
    get: function get() {
      return this._calculateSizeOfBreadcrumbs(this.breadcrumbs, false);
    }
    /**
     * A getter that returns the size - in pixels - of all the shortened breadcrumbs items excluding the last item.
     */

  }, {
    key: 'allShortenedItemsExcludingLast',
    get: function get() {
      return this.shortenedItems.slice(0, this.shortenedItems.length - 1);
    }
  }]);

  return Breadcrumbs;
}();

exports.default = Breadcrumbs;