(function (global, factory) {
  if (typeof define === "function" && define.amd) {
    define(['exports', 'react', 'prop-types', 'styled-components', '../IconSet/Icon'], factory);
  } else if (typeof exports !== "undefined") {
    factory(exports, require('react'), require('prop-types'), require('styled-components'), require('../IconSet/Icon'));
  } else {
    var mod = {
      exports: {}
    };
    factory(mod.exports, global.react, global.propTypes, global.styledComponents, global.Icon);
    global.index = mod.exports;
  }
})(this, function (exports, _react, _propTypes, _styledComponents, _Icon) {
  'use strict';

  Object.defineProperty(exports, "__esModule", {
    value: true
  });

  var _react2 = _interopRequireDefault(_react);

  var _propTypes2 = _interopRequireDefault(_propTypes);

  var _styledComponents2 = _interopRequireDefault(_styledComponents);

  var _Icon2 = _interopRequireDefault(_Icon);

  function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : {
      default: obj
    };
  }

  var Card = _styledComponents2.default.div.withConfig({
    displayName: 'Card'
  })(['display:block;width:100%;padding-bottom:4rem;background-color:var(--px-card-background-color,lightgray);border-top:1px solid var(--px-card-border-color,gray);border:var(--px-card-border);']);
  Card.displayName = 'CardContainer';

  var CardHeader = _styledComponents2.default.header.withConfig({
    displayName: 'Card__CardHeader'
  })(['padding:1rem;padding-top:1.33333rem;border-bottom:1px solid var(--px-card-border-color,transparent);margin-bottom:1rem;display:flex;justify-content:space-between;align-items:center;user-select:none;']);
  CardHeader.displayName = 'CardHeader';

  var CardTitle = _styledComponents2.default.span.withConfig({
    displayName: 'Card__CardTitle'
  })(['height:2rem;line-height:2rem;text-transform:uppercase;color:var(--px-card-header-color,black);']);

  var CardBody = _styledComponents2.default.section.withConfig({
    displayName: 'Card__CardBody'
  })(['padding-left:1rem;padding-right:1rem;', ''], function (props) {
    return props.fullBleed && (0, _styledComponents.css)(['padding:none;']);
  });
  CardBody.displayName = 'CardBody';

  var CardIcon = _styledComponents2.default.i.withConfig({
    displayName: 'Card__CardIcon'
  })(['color:var(--px-card-icon-color,black);color:var(--px-card-action-icon-color,black);cursor:pointer;margin-right:.5rem;&:hover{color:var(--px-card-action-icon-color--hover,blue);}&:active{color:var(--px-card-action-icon-color--pressed,blue);}&:not(:last-of-type){margin-right:.66666rem;}']);
  CardIcon.displayName = 'CardIcon';
  CardIcon.defaultProps = {
    className: 'px-card-icon'
  };

  var CardComponent = function CardComponent(_ref) {
    var headerText = _ref.headerText,
        icon = _ref.icon,
        actions = _ref.actions,
        fullBleed = _ref.fullBleed,
        children = _ref.children;
    return _react2.default.createElement(
      Card,
      { className: 'px-card' },
      _react2.default.createElement(
        CardHeader,
        { className: 'px-card-header' },
        _react2.default.createElement(
          CardTitle,
          null,
          icon && _react2.default.createElement(
            CardIcon,
            null,
            _react2.default.createElement(_Icon2.default, { icon: icon })
          ),
          headerText
        ),
        actions && actions()
      ),
      _react2.default.createElement(
        CardBody,
        { fullBleed: fullBleed, className: 'px-card-body' },
        children
      )
    );
  };

  CardComponent.displayName = 'Card';

  CardComponent.defaultProps = {
    headerText: null,
    icon: null,
    actions: null,
    fullBleed: null,
    children: null
  };

  CardComponent.propTypes = process.env.NODE_ENV !== "production" ? {
    headerText: _propTypes2.default.string,
    icon: _propTypes2.default.string,
    actions: _propTypes2.default.func,
    fullBleed: _propTypes2.default.bool,
    children: _propTypes2.default.node
  } : {};

  exports.default = CardComponent;
});