(function (global, factory) {
  if (typeof define === "function" && define.amd) {
    define(['exports', './AssetGraph', '../../../utils/mitt'], factory);
  } else if (typeof exports !== "undefined") {
    factory(exports, require('./AssetGraph'), require('../../../utils/mitt'));
  } else {
    var mod = {
      exports: {}
    };
    factory(mod.exports, global.AssetGraph, global.mitt);
    global.AssetGraphBehavior = mod.exports;
  }
})(this, function (exports, _AssetGraph, _mitt) {
  'use strict';

  Object.defineProperty(exports, "__esModule", {
    value: true
  });

  var _mitt2 = _interopRequireDefault(_mitt);

  function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : {
      default: obj
    };
  }

  var _typeof = typeof Symbol === "function" && typeof Symbol.iterator === "symbol" ? function (obj) {
    return typeof obj;
  } : function (obj) {
    return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
  };

  function _classCallCheck(instance, Constructor) {
    if (!(instance instanceof Constructor)) {
      throw new TypeError("Cannot call a class as a function");
    }
  }

  var _createClass = function () {
    function defineProperties(target, props) {
      for (var i = 0; i < props.length; i++) {
        var descriptor = props[i];
        descriptor.enumerable = descriptor.enumerable || false;
        descriptor.configurable = true;
        if ("value" in descriptor) descriptor.writable = true;
        Object.defineProperty(target, descriptor.key, descriptor);
      }
    }

    return function (Constructor, protoProps, staticProps) {
      if (protoProps) defineProperties(Constructor.prototype, protoProps);
      if (staticProps) defineProperties(Constructor, staticProps);
      return Constructor;
    };
  }();

  var emitter = new _mitt2.default();

  var assetGraph = function assetGraph(options) {
    return new _AssetGraph.AssetGraph(options);
  };

  var AssetGraphBehavior = function () {
    function AssetGraphBehavior() {
      _classCallCheck(this, AssetGraphBehavior);

      this.items = null;
      this.keys = {
        id: 'id',
        label: 'label',
        children: 'children',
        icon: 'icon'
      };
      this.emitter = emitter;

      this.on = emitter.on;
      this.off = emitter.off;
      this.fire = emitter.emit;
      this.addEventListener = emitter.on;
      this._createAssetGraph = assetGraph.bind(this);
    }

    _createClass(AssetGraphBehavior, [{
      key: 'select',
      value: function select(obj) {
        this.selected = obj;
      }
    }, {
      key: 'activate',
      value: function activate(obj) {
        this.active = obj;
      }
    }, {
      key: '__handleAssetReferenceChanged',
      value: function __handleAssetReferenceChanged(items, keys) {
        if ((typeof items === 'undefined' ? 'undefined' : _typeof(items)) === 'object' && Array.isArray(items)) {
          if (this._assetGraph !== null) {
            if (typeof this.activate === 'function') {
              this.activate(null);
            }
            if (typeof this.select === 'function') {
              this.select(null);
            }
            if (typeof this.favorite === 'function') {
              this.favorite(null);
            }
          }

          this._assetGraph = this._createAssetGraph();
          this._assetGraph.addChildren(null, items, {
            recursive: true,
            childrenKey: keys.children
          });
          this.__rootItems = items.slice(0);
          this.fire('px-app-asset-graph-created', { graph: this._assetGraph });
        }
        return this._assetGraph;
      }
    }, {
      key: '__handleKeyUpdated',
      value: function __handleKeyUpdated(record) {
        if (!this._assetGraph) {
          return;
        }
        if (record.path === 'keys.children') {
          this.__handleAssetReferenceChanged(this.items, this.keys);
        }
        if (record.path === 'keys.id') {
          if (typeof this.activate === 'function') {
            this.activate(null);
          }
          if (typeof this.select === 'function') {
            this.select(null);
          }
          if (typeof this.favorite === 'function') {
            this.favorite(null);
          }
        }
      }
    }, {
      key: 'addChildren',
      value: function addChildren(node, children, options) {
        if (this._assetGraph !== null) {
          this._assetGraph.addChildren(node, children, Object.assign({}, {
            recursive: true,
            childrenKey: this.keys.children
          }, options || {}));
          if (node === null) {
            var childrenArray = Array.isArray(children) ? children : [children];
            this.__rootItems = this.__rootItems.concat(childrenArray);
          }
          this.fire('px-app-asset-children-updated', node === null ? {
            item: null,
            added: children,
            children: this.__rootItems
          } : Object.assign({}, this._assetGraph.getInfo(node), { added: children }));
        }
      }
    }, {
      key: 'removeChildren',
      value: function removeChildren(node, children, options) {
        if (this._assetGraph !== null) {
          var childrenArray = Array.isArray(children) ? children : [children];

          if (typeof this.activate === 'function' || typeof this.select === 'function') {
            var deactivated = void 0;
            var deselected = void 0;

            for (var i = 0; i < childrenArray.length; i++) {
              if (!deactivated && typeof this.activate === 'function' && this.activeMeta && (this.activeMeta.item === childrenArray[i] || this.activeMeta.path && this.activeMeta.path.indexOf(childrenArray[i]) > -1)) {
                this.activate(null);
                deactivated = true;
              }

              if (!deselected && typeof this.select === 'function' && this.selectedMeta && (this.selectedMeta.item === childrenArray[i] || this.selectedMeta.path && this.selectedMeta.path.indexOf(childrenArray[i]) > -1)) {
                this.select(null);
                deactivated = true;
              }
            }
          }

          this._assetGraph.removeChildren(node, children, options);
          if (node === null) {
            this.__rootItems = this.__rootItems.filter(function (item) {
              return childrenArray.indexOf(item) === -1;
            });
          }
          this.fire('px-app-asset-children-updated', node === null ? {
            item: null,
            removed: children,
            children: this.__rootItems
          } : Object.assign({}, this._assetGraph.getInfo(node), { removed: children }));
        }
      }
    }, {
      key: 'items',
      set: function set(val) {
        this.__handleAssetReferenceChanged(val, this.keys);
        return this;
      }
    }]);

    return AssetGraphBehavior;
  }();

  exports.default = AssetGraphBehavior;
});