(function (global, factory) {
  if (typeof define === "function" && define.amd) {
    define(['exports'], factory);
  } else if (typeof exports !== "undefined") {
    factory(exports);
  } else {
    var mod = {
      exports: {}
    };
    factory(mod.exports);
    global.AssetSelectable = mod.exports;
  }
})(this, function (exports) {
  'use strict';

  Object.defineProperty(exports, "__esModule", {
    value: true
  });

  function _toConsumableArray(arr) {
    if (Array.isArray(arr)) {
      for (var i = 0, arr2 = Array(arr.length); i < arr.length; i++) {
        arr2[i] = arr[i];
      }

      return arr2;
    } else {
      return Array.from(arr);
    }
  }

  function _classCallCheck(instance, Constructor) {
    if (!(instance instanceof Constructor)) {
      throw new TypeError("Cannot call a class as a function");
    }
  }

  var _createClass = function () {
    function defineProperties(target, props) {
      for (var i = 0; i < props.length; i++) {
        var descriptor = props[i];
        descriptor.enumerable = descriptor.enumerable || false;
        descriptor.configurable = true;
        if ("value" in descriptor) descriptor.writable = true;
        Object.defineProperty(target, descriptor.key, descriptor);
      }
    }

    return function (Constructor, protoProps, staticProps) {
      if (protoProps) defineProperties(Constructor.prototype, protoProps);
      if (staticProps) defineProperties(Constructor, staticProps);
      return Constructor;
    };
  }();

  var AssetSelectable = function () {
    function AssetSelectable(props) {
      _classCallCheck(this, AssetSelectable);

      this.multiSelect = props.multiSelect || false;
      this._lastSelection = {
        source: null,
        reason: null,
        item: null
      };

      this.selected = this.multiSelect ? [] : null;
      this.selectedRoute = this.multiSelect ? [] : null;
      this.selectedMeta = this.multiSelect ? [] : null;
    }

    _createClass(AssetSelectable, [{
      key: 'set',
      value: function set(name, val) {
        this[name] = val;
      }
    }, {
      key: 'fire',
      value: function fire(name, data) {
        console.log('fire', name, data);
      }
    }, {
      key: '_toggleMultiSelect',
      value: function _toggleMultiSelect(allowMultiSelect) {
        if (allowMultiSelect && !Array.isArray(this.selected)) {
          this.selected = [];
          this.selectedRoute = [];
        }
        if (!allowMultiSelect && Array.isArray(this.selected)) {
          this.selected = this.selected.length ? this.selected[0] : null;
        }
      }
    }, {
      key: 'select',
      value: function select(item) {
        var source = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 'METHOD';

        if (!this.multiSelect && item === null && this._lastSelection.item !== null || this.multiSelect && item === null && this.selected.length || this.multiSelect && Array.isArray(item) && !item.length && this.selected.length) {
          this.deselect(Array.isArray(this.selected) ? [].concat(_toConsumableArray(this.selected)) : this.selected);
          return this.selected;
        }
        if (!item || !this.multiSelect && item === this._lastSelection.item || this.multiSelect && this.selected.indexOf(item) > -1) return this.selected;
        if (this.multiSelect && Array.isArray(item) && item.length) {
          for (var i = 0; i < item.length; i++) {
            this.select(item[i], source);
          }
          return this.selected;
        }

        if (this._assetGraph.hasNode(item)) {
          this._selectAsset(item, source);
          return this.selected;
        }
        throw new Error('The following item could not be found in the items graph:\n      ' + JSON.stringify(item));
      }
    }, {
      key: 'deselect',
      value: function deselect(item) {
        var source = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 'METHOD';

        if (!this.multiSelect && (!item || this.selected === item)) {
          this._deselectAsset(this.selected);
          return this.selected;
        }
        if (this.multiSelect && !item) {
          this.deselect([].concat(_toConsumableArray(this.selected)));
          return this.selected;
        }
        if (this.multiSelect && Array.isArray(item) && this.selected.length) {
          for (var i = 0; i < item.length; i++) {
            this.deselect(item[i], source);
          }
          return this.selected;
        }
        if (this.multiSelect && item && this.selected.indexOf(item) > -1) {
          this._deselectAsset(item);
          return this.selected;
        }
      }
    }, {
      key: '_getSelectedMeta',
      value: function _getSelectedMeta(selected) {
        var _this = this;

        if (selected.base && !Array.isArray(selected.base) && this._assetGraph && this._assetGraph.hasNode(selected.base)) {
          var _assetGraph$getInfo = this._assetGraph.getInfo(selected.base, this.keys.id),
              path = _assetGraph$getInfo.path,
              route = _assetGraph$getInfo.route,
              parent = _assetGraph$getInfo.parent,
              children = _assetGraph$getInfo.children,
              siblings = _assetGraph$getInfo.siblings;

          return {
            item: selected.base,
            path: path,
            route: route,
            parent: parent,
            children: children,
            siblings: siblings
          };
        }
        if (selected.base && Array.isArray(selected.base) && selected.base.length) {
          return selected.base.map(function (item) {
            var _assetGraph$getInfo2 = _this._assetGraph.getInfo(item, _this.keys.id),
                path = _assetGraph$getInfo2.path,
                route = _assetGraph$getInfo2.route,
                parent = _assetGraph$getInfo2.parent,
                children = _assetGraph$getInfo2.children,
                siblings = _assetGraph$getInfo2.siblings;

            return {
              item: item,
              path: path,
              route: route,
              parent: parent,
              children: children,
              siblings: siblings
            };
          });
        }
        return {
          item: null,
          path: null,
          route: null,
          parent: null,
          children: null,
          siblings: null
        };
      }
    }, {
      key: '_assetSelectedByEvent',
      value: function _assetSelectedByEvent(evt) {
        evt.stopPropagation();
        if (evt.detail.item) {
          this.select(evt.detail.item, 'DOM_EVENT');
        }
      }
    }, {
      key: '_assetDeselectedByEvent',
      value: function _assetDeselectedByEvent(evt) {
        evt.stopPropagation();
        if (evt.detail.item) {
          this.deselect(evt.detail.item, 'DOM_EVENT');
        }
      }
    }, {
      key: '_selectedRouteChanged',
      value: function _selectedRouteChanged(ref) {
        if (!ref || !ref.path || !this._assetGraph || this._squashSelectedRouteChange) return;

        if (!this.multiSelect && ref.path === 'selectedRoute') {
          this._updateSelectedFromRoute(ref.base);
        }

        if (this.multiSelect && (ref.path === 'selectedRoute' || ref.path == 'selectedRoute.splices')) {
          this._updateSelectedFromRouteMulti(ref.base);
        }
      }
    }, {
      key: '_updateSelectedFromRoute',
      value: function _updateSelectedFromRoute(route) {
        if (!this.selected && (route === null || Array.isArray(route) && !route.length)) {
          return;
        }
        if (this.selected && (route === null || Array.isArray(route) && !route.length)) {
          this._squashSelectedChange = true;
          this.deselect(this.selected, 'ROUTE_CHANGED');
          this._squashSelectedChange = false;
          return;
        }

        var item = this._assetGraph.getNodeAtRoute(route, this.keys.id);
        if (item === this.selected) {} else if (item) {
          this.select(item, 'ROUTE_CHANGED');
        } else {
          throw new Error('The route ' + JSON.stringify(route) + ' could not be found in the items graph.');
        }
      }
    }, {
      key: '_updateSelectedFromRouteMulti',
      value: function _updateSelectedFromRouteMulti(route) {
        var _this2 = this;

        if (this.selected.length && (route === null || Array.isArray(route) && !route.length)) {
          this._squashSelectedChange = true;
          this.deselect(null, 'ROUTE_CHANGED');
          this._squashSelectedChange = false;
          return;
        }

        if (Array.isArray(route)) {
          for (var i = 0; i < route.length; i++) {
            this._squashSelectedChange = true;
            this.selected = route.map(function (route) {
              var item = _this2._assetGraph.getNodeAtRoute(route, _this2.keys.id);
              if (!item) {
                throw new Error('The following item could not be found in the items graph:\n              ' + JSON.stringify(item));
              }

              return item;
            });
            this._squashSelectedChange = false;
          }
        }
      }
    }, {
      key: '_selectedChanged',
      value: function _selectedChanged(ref) {
        if (!ref || !ref.path || this._squashSelectedChange || !this._assetGraph) return;

        if (!this.multiSelect && ref.path === 'selected' && typeof this.selectedRoute !== 'undefined') {
          this._updateSelectedRoute(ref.base);
        }

        if (this.multiSelect && (ref.path === 'selected' || ref.path === 'selected.splices') && typeof this.selectedRoute !== 'undefined') {
          this._updateSelectedRouteMulti(ref.base);
        }
      }
    }, {
      key: '_checkIfEmpty',
      value: function _checkIfEmpty(item) {
        if (Array.isArray(item)) return !!item.length;
        return !!item;
      }
    }, {
      key: '_updateSelectedRoute',
      value: function _updateSelectedRoute(selected) {
        if (this._checkIfEmpty(selected)) {
          if (!this._assetGraph.hasNode(selected)) {
            throw new Error('The following item could not be found in the items graph:\n          ' + JSON.stringify(selected));
          }

          var route = this._assetGraph.getRoute(selected, this.keys.id);
          if (this._routeIsDifferent(route, this.selectedRoute)) {
            this._squashSelectedRouteChange = true;
            this.selectedRoute = route;
            this._squashSelectedRouteChange = false;
          }
        } else {
          this._squashSelectedRouteChange = true;
          this.selectedRoute = null;
          this._squashSelectedRouteChange = false;
        }
      }
    }, {
      key: '_updateSelectedRouteMulti',
      value: function _updateSelectedRouteMulti(selected) {
        var _this3 = this;

        if (selected && Array.isArray(selected) && selected.length) {
          this._squashSelectedRouteChange = true;
          this.selectedRoute = selected.map(function (item) {
            if (!_this3._assetGraph.hasNode(item)) {
              throw new Error('The following item could not be found in the items graph:\n            ' + JSON.stringify(item));
            }

            return _this3._assetGraph.getRoute(item, _this3.keys.id);
          });
          this._squashSelectedRouteChange = false;
        } else {
          this._squashSelectedRouteChange = true;
          this.selectedRoute = [];
          this._squashSelectedRouteChange = false;
        }
      }
    }, {
      key: '__selectInitialAssets',
      value: function __selectInitialAssets() {
        if (!this.multiSelect && this.selected && !this.selectedRoute) {
          this._updateSelectedRoute(this.selected);
        } else if (!this.multiSelect && !this.selected && this.selectedRoute) {
          this._updateSelectedFromRoute(this.selectedRoute);
        } else if (this.multiSelect && !!this.selected && this.selected.length && !this.selectedRoute.length) {
          this._updateSelectedRouteMulti(this.selected);
        } else if (this.multiSelect && !!this.selected && !this.selected.length && this.selectedRoute.length) {
          this._updateSelectedFromRouteMulti(this.selected);
        }
      }
    }, {
      key: '_routeIsDifferent',
      value: function _routeIsDifferent(r1, r2) {
        if (!r1 || !r2) return true;
        if (r1.length !== r2.length) return true;
        for (var i = 0; i < r1.length; i++) {
          if (r1[i] !== r2[i]) return true;
        }
        return false;
      }
    }, {
      key: '_selectAsset',
      value: function _selectAsset(item, source) {
        var _assetGraph$getInfo3 = this._assetGraph.getInfo(item, this.keys.id),
            route = _assetGraph$getInfo3.route,
            path = _assetGraph$getInfo3.path;

        this._lastSelection = {
          item: item,
          source: source,
          route: route
        };
        if (!this.multiSelect) {
          this.selected = item;
        }
        if (this.multiSelect) {
          this.push('selected', item);
        }
        this.fire('px-app-asset-selected', {
          source: source,
          item: item,
          route: route,
          path: path
        });
      }
    }, {
      key: '_deselectAsset',
      value: function _deselectAsset(item, source) {
        var _assetGraph$getInfo4 = this._assetGraph.getInfo(item, this.keys.id),
            route = _assetGraph$getInfo4.route,
            path = _assetGraph$getInfo4.path;

        this._lastSelection = {
          item: null,
          source: null,
          route: null
        };
        if (!this.multiSelect) {
          this.set('selected', null);
          this.fire('px-app-asset-deselected', {
            source: source,
            item: item,
            route: route,
            path: path
          });
        }
        if (this.multiSelect) {
          this.splice('selected', this.selected.indexOf(item), 1);
          this.fire('px-app-asset-deselected', {
            source: source,
            item: item,
            route: route,
            path: path
          });
        }
      }
    }, {
      key: 'multiSelect',
      get: function get() {
        return this._multiSelect;
      },
      set: function set(val) {
        if (val !== this._multiSelect) {
          this._multiSelect = val;
          this._toggleMultiSelect(val);
        }
      }
    }]);

    return AssetSelectable;
  }();

  exports.default = AssetSelectable;
});