(function (global, factory) {
  if (typeof define === "function" && define.amd) {
    define(['exports', 'react', 'prop-types', 'styled-components'], factory);
  } else if (typeof exports !== "undefined") {
    factory(exports, require('react'), require('prop-types'), require('styled-components'));
  } else {
    var mod = {
      exports: {}
    };
    factory(mod.exports, global.react, global.propTypes, global.styledComponents);
    global.index = mod.exports;
  }
})(this, function (exports, _react, _propTypes, _styledComponents) {
  'use strict';

  Object.defineProperty(exports, "__esModule", {
    value: true
  });

  var _react2 = _interopRequireDefault(_react);

  var _propTypes2 = _interopRequireDefault(_propTypes);

  var _styledComponents2 = _interopRequireDefault(_styledComponents);

  function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : {
      default: obj
    };
  }

  var Drawer = _styledComponents2.default.div.withConfig({
    displayName: 'Drawer'
  })(['position:fixed;z-index:var(--px-drawer-z-index,100);color:var(--px-drawer-font-color,black);background-color:var(--px-drawer-background-color,white);width:var(--px-drawer-width,256px);height:var(--px-drawer-height,100%);box-shadow:var(--px-drawer-box-shadow,rgba(0,0,0,0.16) 0 1px 4px,rgba(0,0,0,0.23) 0 1px 4px);transition:var(--px-drawer-transition,transform 350ms cubic-bezier(0.23,1,0.32,1));', ' ', ' ', ' ', ' &::after{position:fixed;top:56px;bottom:0;left:100%;visibility:visible;width:20px;content:"";}', ' ', ''], function (props) {
    return props.anchor === 'left' && (0, _styledComponents.css)(['top:0;left:0;right:auto;transform:translateX(-110%);', ''], props.opened && (0, _styledComponents.css)(['transform:translateX(0);']));
  }, function (props) {
    return props.anchor === 'right' && (0, _styledComponents.css)(['top:0;left:auto;right:0;transform:translateX(110%);', ''], props.opened && (0, _styledComponents.css)(['transform:translateX(0);']));
  }, function (props) {
    return props.anchor === 'top' && (0, _styledComponents.css)(['top:0;left:0;bottom:auto;right:0;height:auto;max-height:100vh;transform:translateY(-110%);width:100%;', ''], props.opened && (0, _styledComponents.css)(['transform:translateY(0);']));
  }, function (props) {
    return props.anchor === 'bottom' && (0, _styledComponents.css)(['top:auto;left:0;bottom:0;right:0;height:auto;max-height:100vh;width:100%;transform:translateY(105%);width:100%;', ''], props.opened && (0, _styledComponents.css)(['transform:translateY(0);']));
  }, function (props) {
    return props.opened && (0, _styledComponents.css)(['z-index:var(--px-drawer-z-index,25);visibility:visible;']);
  }, function (props) {
    return props.docked && (0, _styledComponents.css)(['z-index:var(--px-drawer-z-index,25);visibility:visible;transform:translateX(0);flex:0 0 auto;']);
  });
  Drawer.displayName = 'Drawer';
  Drawer.defaultProps = {
    className: 'px-drawer'
  };

  var DrawerContent = _styledComponents2.default.div.withConfig({
    displayName: 'Drawer__DrawerContent'
  })(['overflow-x:hidden;overflow-y:auto;display:flex;flex-direction:column;-webkit-overflow-scrolling:touch;height:100%;flex:1 0 auto;']);
  DrawerContent.displayName = 'DrawerContent';
  DrawerContent.defaultProps = {
    className: 'px-drawer-content'
  };

  var DrawerOverlay = _styledComponents2.default.div.withConfig({
    displayName: 'Drawer__DrawerOverlay'
  })(['position:fixed;top:0;right:0;bottom:0;left:0;transition:opacity 0.2s ease;transform:translateZ(0);opacity:0;background:var(--px-drawer-overlay-background,rgba(0,0,0,0.5));z-index:-1;visibility:hidden;', ''], function (props) {
    return props.opened && (0, _styledComponents.css)(['opacity:1;z-index:15;visibility:visible;display:block;']);
  });
  DrawerOverlay.displayName = 'DrawerOverlay';
  DrawerOverlay.defaultProps = {
    className: 'px-drawer-overlay'
  };

  var DrawerComponent = function DrawerComponent(_ref) {
    var fixed = _ref.fixed,
        overlay = _ref.overlay,
        onOverlayClick = _ref.onOverlayClick,
        opened = _ref.opened,
        docked = _ref.docked,
        type = _ref.type,
        anchor = _ref.anchor,
        children = _ref.children;
    return _react2.default.createElement(
      'div',
      null,
      _react2.default.createElement(
        Drawer,
        { opened: opened, anchor: anchor, fixed: fixed, docked: docked, type: type },
        _react2.default.createElement(
          DrawerContent,
          null,
          children
        )
      ),
      overlay && _react2.default.createElement(DrawerOverlay, { onClick: onOverlayClick, opened: opened })
    );
  };

  DrawerComponent.propTypes = process.env.NODE_ENV !== "production" ? {
    opened: _propTypes2.default.bool,
    fixed: _propTypes2.default.bool,
    docked: _propTypes2.default.bool,
    overlay: _propTypes2.default.bool,
    anchor: _propTypes2.default.string,
    onOverlayClick: _propTypes2.default.func,
    type: _propTypes2.default.string,
    children: _propTypes2.default.node
  } : {};

  DrawerComponent.defaultProps = {
    opened: false,
    fixed: false,
    overlay: false,
    docked: false,
    onOverlayClick: null,
    type: null,
    children: null,
    anchor: 'left'
  };

  exports.default = DrawerComponent;
});