(function (global, factory) {
  if (typeof define === "function" && define.amd) {
    define(['exports', 'react', 'prop-types', 'styled-components', '../Overlay', '../Button'], factory);
  } else if (typeof exports !== "undefined") {
    factory(exports, require('react'), require('prop-types'), require('styled-components'), require('../Overlay'), require('../Button'));
  } else {
    var mod = {
      exports: {}
    };
    factory(mod.exports, global.react, global.propTypes, global.styledComponents, global.Overlay, global.Button);
    global.index = mod.exports;
  }
})(this, function (exports, _react, _propTypes, _styledComponents, _Overlay, _Button) {
  'use strict';

  Object.defineProperty(exports, "__esModule", {
    value: true
  });

  var _react2 = _interopRequireDefault(_react);

  var _propTypes2 = _interopRequireDefault(_propTypes);

  var _styledComponents2 = _interopRequireDefault(_styledComponents);

  var _Overlay2 = _interopRequireDefault(_Overlay);

  var _Button2 = _interopRequireDefault(_Button);

  function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : {
      default: obj
    };
  }

  var Modal = _styledComponents2.default.div.withConfig({
    displayName: 'Modal'
  })(['position:absolute;background-color:transparent;visibility:hidden;', ' ', ' ', ''], function (props) {
    return props.zIndex && (0, _styledComponents.css)(['z-index:', ''], props.zIndex);
  }, function (props) {
    return props.fixed && (0, _styledComponents.css)(['position:fixed;']);
  }, function (props) {
    return props.opened && (0, _styledComponents.css)(['visibility:visible;']);
  });

  var ModalContent = _styledComponents2.default.div.withConfig({
    displayName: 'Modal__ModalContent'
  })(['z-index:900;', ' top:50%;left:50%;transform:translate(-50%,-50%);max-height:calc(100% - 2rem);max-width:calc(100% - 2rem);overflow:auto;white-space:normal;word-wrap:break-word;background-color:var(--px-modal-background-color,white);color:var(--px-modal-text-color,black);box-shadow:0 6px 12px 0 rgba(0,0,0,0.2);padding:1rem;position:fixed;', ' @media screen and (max-width:44.9375em){width:100%;}@media screen and (min-width:45em){min-width:400px;}'], function (props) {
    return props.zIndex && (0, _styledComponents.css)(['z-index:', ''], props.zIndex);
  }, function (props) {
    return props.fixed && (0, _styledComponents.css)(['position:fixed;']);
  });
  ModalContent.displayName = 'ModalContent';

  var ModalTitle = _styledComponents2.default.h3.withConfig({
    displayName: 'Modal__ModalTitle'
  })(['margin-bottom:1rem;margin-top:0;font-size:1.33333rem;line-height:1;font-weight:400;']);
  ModalTitle.displayName = 'ModalTitle';

  var ModalBody = _styledComponents2.default.div.withConfig({
    displayName: 'Modal__ModalBody'
  })(['']);
  var ModalActions = _styledComponents2.default.div.withConfig({
    displayName: 'Modal__ModalActions'
  })(['display:flex;justify-content:flex-end;align-items:flex-end;margin-top:1rem;border-top:1px solid var(--px-modal-border-color,transparent);button:nth-last-of-type(2){margin-right:1rem;}']);

  var Component = function Component(_ref) {
    var headerText = _ref.headerText,
        actions = _ref.actions,
        rejectText = _ref.rejectText,
        onBtnModalNegativeClick = _ref.onBtnModalNegativeClick,
        acceptText = _ref.acceptText,
        onBtnModalPositiveClick = _ref.onBtnModalPositiveClick,
        opened = _ref.opened,
        onBackdropClick = _ref.onBackdropClick,
        btnModalPositiveDisabled = _ref.btnModalPositiveDisabled,
        children = _ref.children,
        fixed = _ref.fixed,
        zIndex = _ref.zIndex,
        modalContentElement = _ref.modalContentElement;
    return _react2.default.createElement(
      Modal,
      { opened: opened, fixed: fixed, zIndex: zIndex },
      _react2.default.createElement(_Overlay2.default, { opened: opened, onOverlayClick: function onOverlayClick(e) {
          return onBackdropClick(e);
        } }),
      _react2.default.createElement(
        ModalContent,
        { role: 'region', fixed: fixed, zIndex: zIndex },
        modalContentElement && modalContentElement,
        !modalContentElement && _react2.default.createElement(
          'div',
          null,
          _react2.default.createElement(
            ModalTitle,
            null,
            headerText
          ),
          _react2.default.createElement(
            ModalBody,
            null,
            children
          ),
          _react2.default.createElement(
            ModalActions,
            null,
            actions && actions(),
            rejectText && _react2.default.createElement(
              _Button2.default,
              {
                id: 'btnModalNegative',
                onClick: onBtnModalNegativeClick
              },
              rejectText
            ),
            acceptText && _react2.default.createElement(
              _Button2.default,
              {
                theme: 'primary',
                id: 'btnModalPositive',
                disabled: btnModalPositiveDisabled,
                onClick: onBtnModalPositiveClick
              },
              acceptText
            )
          )
        )
      )
    );
  };

  Component.defaultProps = {
    headerText: null,
    actions: null,
    rejectText: null,
    acceptText: null,
    onBackdropClick: null,
    onBtnModalNegativeClick: null,
    onBtnModalPositiveClick: null,
    btnModalPositiveDisabled: null,
    opened: null,
    children: null,
    fixed: null,
    zIndex: null,
    modalContentElement: null
  };
  Component.propTypes = process.env.NODE_ENV !== "production" ? {
    headerText: _propTypes2.default.string,
    actions: _propTypes2.default.node,
    rejectText: _propTypes2.default.string,
    acceptText: _propTypes2.default.string,
    onBackdropClick: _propTypes2.default.func,
    onBtnModalNegativeClick: _propTypes2.default.func,
    onBtnModalPositiveClick: _propTypes2.default.func,
    btnModalPositiveDisabled: _propTypes2.default.bool,
    opened: _propTypes2.default.bool,
    children: _propTypes2.default.node,
    fixed: _propTypes2.default.bool,
    zIndex: _propTypes2.default.number,
    modalContentElement: _propTypes2.default.oneOfType([_propTypes2.default.node, _propTypes2.default.func])
  } : {};

  exports.default = Component;
});