(function (global, factory) {
  if (typeof define === "function" && define.amd) {
    define(['exports', 'react', 'prop-types', 'classnames', './PopperContent', '../utils'], factory);
  } else if (typeof exports !== "undefined") {
    factory(exports, require('react'), require('prop-types'), require('classnames'), require('./PopperContent'), require('../utils'));
  } else {
    var mod = {
      exports: {}
    };
    factory(mod.exports, global.react, global.propTypes, global.classnames, global.PopperContent, global.utils);
    global.index = mod.exports;
  }
})(this, function (exports, _react, _propTypes, _classnames, _PopperContent, _utils) {
  'use strict';

  Object.defineProperty(exports, "__esModule", {
    value: true
  });

  var _react2 = _interopRequireDefault(_react);

  var _propTypes2 = _interopRequireDefault(_propTypes);

  var _classnames2 = _interopRequireDefault(_classnames);

  var _PopperContent2 = _interopRequireDefault(_PopperContent);

  function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : {
      default: obj
    };
  }

  var _extends = Object.assign || function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };

  var _typeof = typeof Symbol === "function" && typeof Symbol.iterator === "symbol" ? function (obj) {
    return typeof obj;
  } : function (obj) {
    return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
  };

  function _classCallCheck(instance, Constructor) {
    if (!(instance instanceof Constructor)) {
      throw new TypeError("Cannot call a class as a function");
    }
  }

  var _createClass = function () {
    function defineProperties(target, props) {
      for (var i = 0; i < props.length; i++) {
        var descriptor = props[i];
        descriptor.enumerable = descriptor.enumerable || false;
        descriptor.configurable = true;
        if ("value" in descriptor) descriptor.writable = true;
        Object.defineProperty(target, descriptor.key, descriptor);
      }
    }

    return function (Constructor, protoProps, staticProps) {
      if (protoProps) defineProperties(Constructor.prototype, protoProps);
      if (staticProps) defineProperties(Constructor, staticProps);
      return Constructor;
    };
  }();

  function _possibleConstructorReturn(self, call) {
    if (!self) {
      throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
    }

    return call && (typeof call === "object" || typeof call === "function") ? call : self;
  }

  function _inherits(subClass, superClass) {
    if (typeof superClass !== "function" && superClass !== null) {
      throw new TypeError("Super expression must either be null or a function, not " + typeof superClass);
    }

    subClass.prototype = Object.create(superClass && superClass.prototype, {
      constructor: {
        value: subClass,
        enumerable: false,
        writable: true,
        configurable: true
      }
    });
    if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass;
  }

  var DEFAULT_DELAYS = {
    show: 0,
    hide: 0
  };

  var defaultProps = {
    isOpen: false,
    disabled: false,
    target: null,
    innerClassName: null,
    cssModule: null,
    className: null,
    container: null,
    modifiers: null,
    hideArrow: false,
    placement: 'right',
    placementPrefix: 'bs-popover',
    delay: DEFAULT_DELAYS,
    toggle: function toggle() {}
  };

  var Popover = function (_React$Component) {
    _inherits(Popover, _React$Component);

    function Popover(props) {
      _classCallCheck(this, Popover);

      var _this = _possibleConstructorReturn(this, (Popover.__proto__ || Object.getPrototypeOf(Popover)).call(this, props));

      _this.addTargetEvents = _this.addTargetEvents.bind(_this);
      _this.handleDocumentClick = _this.handleDocumentClick.bind(_this);
      _this.removeTargetEvents = _this.removeTargetEvents.bind(_this);
      _this.getRef = _this.getRef.bind(_this);
      _this.toggle = _this.toggle.bind(_this);
      _this.show = _this.show.bind(_this);
      _this.hide = _this.hide.bind(_this);
      return _this;
    }

    _createClass(Popover, [{
      key: 'componentDidMount',
      value: function componentDidMount() {
        this._target = (0, _utils.getTarget)(this.props.target);
        this.handleProps();
      }
    }, {
      key: 'componentDidUpdate',
      value: function componentDidUpdate() {
        this.handleProps();
      }
    }, {
      key: 'componentWillUnmount',
      value: function componentWillUnmount() {
        this.clearShowTimeout();
        this.clearHideTimeout();
        this.removeTargetEvents();
      }
    }, {
      key: 'getRef',
      value: function getRef(ref) {
        this._popover = ref;
      }
    }, {
      key: 'getDelay',
      value: function getDelay(key) {
        var delay = this.props.delay;

        if ((typeof delay === 'undefined' ? 'undefined' : _typeof(delay)) === 'object') {
          return delay[key] === 'NaN' ? DEFAULT_DELAYS[key] : delay[key];
        }
        return delay;
      }
    }, {
      key: 'handleProps',
      value: function handleProps() {
        if (this.props.isOpen) {
          this.show();
        } else {
          this.hide();
        }
      }
    }, {
      key: 'show',
      value: function show() {
        this.clearHideTimeout();
        this.addTargetEvents();
        if (!this.props.isOpen) {
          this.clearShowTimeout();
          this._showTimeout = setTimeout(this.toggle, this.getDelay('show'));
        }
      }
    }, {
      key: 'hide',
      value: function hide() {
        this.clearShowTimeout();
        this.removeTargetEvents();
        if (this.props.isOpen) {
          this.clearHideTimeout();
          this._hideTimeout = setTimeout(this.toggle, this.getDelay('hide'));
        }
      }
    }, {
      key: 'clearShowTimeout',
      value: function clearShowTimeout() {
        clearTimeout(this._showTimeout);
        this._showTimeout = undefined;
      }
    }, {
      key: 'clearHideTimeout',
      value: function clearHideTimeout() {
        clearTimeout(this._hideTimeout);
        this._hideTimeout = undefined;
      }
    }, {
      key: 'handleDocumentClick',
      value: function handleDocumentClick(e) {
        if (e.target !== this._target && !this._target.contains(e.target) && e.target !== this._popover && !(this._popover && this._popover.contains(e.target))) {
          if (this._hideTimeout) {
            this.clearHideTimeout();
          }

          if (this.props.isOpen) {
            this.toggle(e);
          }
        }
      }
    }, {
      key: 'addTargetEvents',
      value: function addTargetEvents() {
        var _this2 = this;

        ['click', 'touchstart'].forEach(function (event) {
          return document.addEventListener(event, _this2.handleDocumentClick, true);
        });
      }
    }, {
      key: 'removeTargetEvents',
      value: function removeTargetEvents() {
        var _this3 = this;

        ['click', 'touchstart'].forEach(function (event) {
          return document.removeEventListener(event, _this3.handleDocumentClick, true);
        });
      }
    }, {
      key: 'toggle',
      value: function toggle(e) {
        if (this.props.disabled) {
          return e && e.preventDefault();
        }

        return this.props.toggle(e);
      }
    }, {
      key: 'render',
      value: function render() {
        if (!this.props.isOpen) {
          return null;
        }

        var attributes = (0, _utils.omit)(this.props, Object.keys(_propTypes2.default));
        var classes = (0, _utils.mapToCssModules)((0, _classnames2.default)('popover-inner', this.props.innerClassName), this.props.cssModule);

        var popperClasses = (0, _classnames2.default)('popover', 'show', 'bs-popover-' + this.props.placement, this.props.className);

        return _react2.default.createElement(
          _PopperContent2.default,
          {
            className: popperClasses,
            target: this.props.target,
            isOpen: this.props.isOpen,
            hideArrow: this.props.hideArrow,
            placement: this.props.placement,
            placementPrefix: this.props.placementPrefix,
            container: this.props.container,
            modifiers: this.props.modifiers
          },
          _react2.default.createElement('div', _extends({}, attributes, { className: classes, ref: this.getRef })),
          _react2.default.createElement(
            'style',
            null,
            '\n        .popover{\n          top: 0;\n          left: 0;\n          z-index: 1060;\n          max-width: 276px;\n          font-style: normal;\n          font-weight: 400;\n          line-height: 1.5;\n          text-align: left;\n          text-decoration: none;\n          text-shadow: none;\n          text-transform: none;\n          letter-spacing: normal;\n          word-break: normal;\n          word-spacing: normal;\n          white-space: normal;\n          line-break: auto;\n          font-size: 1rem;\n          word-wrap: break-word;\n          background-clip: padding-box;\n          border: 1px solid var(--px-popover-border-color, #000);\n          background: var(--px-popover-background-color, #fff);\n          color: var(--px-popover-text-color, #000);\n          box-shadow: 0 1px 3px 0 var(--px-popover-shadow-color, #000);\n          position: absolute;\n          display: block;\n        }\n          .popover,\n          .popover .arrow {\n              position: absolute;\n              display: block\n          }\n\n          .popover .arrow {\n              width: 1rem;\n              height: .5rem;\n              margin: 0 .3rem\n          }\n\n          .popover .arrow:after,.popover .arrow:before {\n              position: absolute;\n              display: block;\n              content: "";\n              border-color: transparent;\n              border-style: solid\n          }\n\n          .bs-popover-auto[x-placement^=top],.bs-popover-top {\n              margin-bottom: .5rem\n          }\n\n          .bs-popover-auto[x-placement^=top] .arrow,.bs-popover-top .arrow {\n              bottom: calc((.5rem + 1px) * -1)\n          }\n\n          .bs-popover-auto[x-placement^=top] .arrow:after,.bs-popover-auto[x-placement^=top] .arrow:before,.bs-popover-top .arrow:after,.bs-popover-top .arrow:before {\n              border-width: .5rem .5rem 0\n          }\n\n          .bs-popover-auto[x-placement^=top] .arrow:before,.bs-popover-top .arrow:before {\n              bottom: 0;\n              border-top-color: rgba(0,0,0,.25)\n          }\n\n          .bs-popover-auto[x-placement^=top] .arrow:after,.bs-popover-top .arrow:after {\n              bottom: 1px;\n              border-top-color: #fff\n          }\n\n          .bs-popover-auto[x-placement^=right],.bs-popover-right {\n              margin-left: .5rem\n          }\n\n          .bs-popover-auto[x-placement^=right] .arrow,.bs-popover-right .arrow {\n              left: calc((.5rem + 1px) * -1);\n              width: .5rem;\n              height: 1rem;\n              margin: .3rem 0\n          }\n\n          .bs-popover-auto[x-placement^=right] .arrow:after,.bs-popover-auto[x-placement^=right] .arrow:before,.bs-popover-right .arrow:after,.bs-popover-right .arrow:before {\n              border-width: .5rem .5rem .5rem 0\n          }\n\n          .bs-popover-auto[x-placement^=right] .arrow:before,.bs-popover-right .arrow:before {\n              left: 0;\n              border-right-color: rgba(0,0,0,.25)\n          }\n\n          .bs-popover-auto[x-placement^=right] .arrow:after,.bs-popover-right .arrow:after {\n              left: 1px;\n              border-right-color: #fff\n          }\n\n          .bs-popover-auto[x-placement^=bottom],.bs-popover-bottom {\n              margin-top: .5rem\n          }\n\n          .bs-popover-auto[x-placement^=bottom] .arrow,.bs-popover-bottom .arrow {\n              top: calc((.5rem + 1px) * -1)\n          }\n\n          .bs-popover-auto[x-placement^=bottom] .arrow:after,.bs-popover-auto[x-placement^=bottom] .arrow:before,.bs-popover-bottom .arrow:after,.bs-popover-bottom .arrow:before {\n              border-width: 0 .5rem .5rem\n          }\n\n          .bs-popover-auto[x-placement^=bottom] .arrow:before,.bs-popover-bottom .arrow:before {\n              top: 0;\n              border-bottom-color: rgba(0,0,0,.25)\n          }\n\n          .bs-popover-auto[x-placement^=bottom] .arrow:after,.bs-popover-bottom .arrow:after {\n              top: 1px;\n              border-bottom-color: #fff\n          }\n\n          .bs-popover-auto[x-placement^=bottom] .popover-header:before,.bs-popover-bottom .popover-header:before {\n              position: absolute;\n              top: 0;\n              left: 50%;\n              display: block;\n              width: 1rem;\n              margin-left: -.5rem;\n              content: "";\n              border-bottom: 1px solid #f7f7f7\n          }\n\n          .bs-popover-auto[x-placement^=left],.bs-popover-left {\n              margin-right: .5rem\n          }\n\n          .bs-popover-auto[x-placement^=left] .arrow,.bs-popover-left .arrow {\n              right: calc((.5rem + 1px) * -1);\n              width: .5rem;\n              height: 1rem;\n              margin: .3rem 0\n          }\n\n          .bs-popover-auto[x-placement^=left] .arrow:after,.bs-popover-auto[x-placement^=left] .arrow:before,.bs-popover-left .arrow:after,.bs-popover-left .arrow:before {\n              border-width: .5rem 0 .5rem .5rem\n          }\n\n          .bs-popover-auto[x-placement^=left] .arrow:before,.bs-popover-left .arrow:before {\n              right: 0;\n              border-left-color: rgba(0,0,0,.25)\n          }\n\n          .bs-popover-auto[x-placement^=left] .arrow:after,.bs-popover-left .arrow:after {\n              right: 1px;\n              border-left-color: #fff\n          }\n        '
          )
        );
      }
    }]);

    return Popover;
  }(_react2.default.Component);

  Popover.defaultProps = defaultProps;

  Popover.propTypes = process.env.NODE_ENV !== "production" ? {
    innerClassName: _propTypes2.default.string,
    target: _propTypes2.default.element,
    container: _propTypes2.default.element,
    cssModule: _propTypes2.default.objectOf(_propTypes2.default.string),
    modifiers: _propTypes2.default.objectOf(_propTypes2.default.string),
    disabled: _propTypes2.default.bool,
    isOpen: _propTypes2.default.bool,
    hideArrow: _propTypes2.default.bool,
    placement: _propTypes2.default.string,
    placementPrefix: _propTypes2.default.string,
    className: _propTypes2.default.string,
    delay: _propTypes2.default.shape({
      show: _propTypes2.default.number,
      hide: _propTypes2.default.number
    }),
    toggle: _propTypes2.default.func
  } : {};

  exports.default = Popover;
});